@@ -2,6 +2,7 @@
 # -*- encoding: utf-8 -*-
 
 
+#TODO: Move the imports out. setup related
 class Github(object):
     """
     You can preconfigure all services globally with a ``config`` dict. See
@@ -14,9 +15,11 @@ class Github(object):
 
     def __init__(self, **config):
         from pygithub3.services.users import User
-        from pygithub3.services.repos import Repos
+        from pygithub3.services.repos import Repo
+        from pygithub3.services.gists import Gist
         self._users = User(**config)
-        self._repos = Repos(**config)
+        self._repos = Repo(**config)
+        self._gists = Gist(**config)
 
     @property
     def remaining_requests(self):
@@ -27,7 +30,7 @@ class Github(object):
     @property
     def users(self):
         """
-        :ref:`User service <User service>`
+        :ref:`Users service <Users service>`
         """
         return self._users
 
@@ -37,3 +40,10 @@ class Github(object):
         :ref:`Repos service <Repos service>`
         """
         return self._repos
+
+    @property
+    def gists(self):
+        """
+        :ref:`Gists service <Gists service>`
+        """
+        return self._gists
